| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeigootsvqpk6th5xpdtzanxum3earifrrezfyhylfrit7yvqdrtgpe` | A protocol for ABCI requests and responses.                                                                                |
| connection/valory/abci/0.1.0                                  | `bafybeicasheudousm2unmh5qmy5n3qdq5hmkg2j42fxfm2crxmgq3nzjkq` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeiau32pzy55ta6ugl2bebevlxudal6pnlfomhplfm5mph6reaw3krq` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeie4iivrxcd5dcwzj3y2t66mc5mdvtsuqu426gk2kcdc6fxbki6neu` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeic4nnvvbm7ub5b2wpbgjixlpcygo7zbelasc3bhw5vurnrrrnvkau` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeiaf5ub3awwjyfhg7njnyysch3m5ywps35vbvw7cqfhudsm4wjhjrq` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeihtfmbzsjwsz7kmujzc4bofyoxckekbdi643f762tj3fe4witgjqu` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeifqzq3lcnnck5jw5p5b7tekumkx7jf2nugqx2peljpy3nsiuizrmq` | Service Manager contract                                                                                                   |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeigczbvw4ncvtkcskxsuiiynmlyeowvvdzml2rcmzdlavtyucq34lq` | IPFS e2e testing application.                                                                                              |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeibhgs5gbvnmzvjohglmv7xsgrr35222jon2ko7fdikbqx3afbunpe` | Agent for testing the ABCI connection.                                                                                     |
| contract/valory/service_registry/0.1.0                        | `bafybeif6x4zvsokwcetbrjdb4uyv4l3pqx756cg2ohv2zgcky5yuiwuqvi` | Service Registry contract                                                                                                  |
| protocol/valory/tendermint/0.1.0                              | `bafybeidjqmwvgi4rqgp65tbkhmi45fwn2odr5ecezw6q47hwitsgyw4jpa` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeibjzhsengtxfofqpxy6syamplevp35obemwfp4c5lhag3v2bvgysa` | A protocol specification for IPFS requests and responses.                                                                  |
| skill/valory/abstract_abci/0.1.0                              | `bafybeicg7dv7cff34nv2k2z47c4yp4kddsxp3wozonzow6tnvfvwndz3cy` | The abci skill provides a template of an ABCI application.                                                                 |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeigvqg4lapdaa23dpc3pv67rdptdhey6e435mxqsw2gb2u74yw4yei` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeigxjcci53vwytymzlhr37436yvenh7jup4astrn7dgyixo24aq2pq` | abstract round-based ABCI application                                                                                      |
| contract/valory/multisend/0.1.0                               | `bafybeie7m7pjbnw7cccpbvmbgkut24dtlt4cgvug3tbac7gej37xvwbv3a` | MultiSend contract                                                                                                         |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeidpsnguxizkpihtkqzojr3em7yy7c6qc7gxpbh5vglmwws5wke7bi` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeibc4kczqbh23sc6tufrzn3axmhp3vjav7fa3u6cnpvolrbbc2fd7i` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeid445uy6wwvugf3byzl7r73c7teu6xr5ezxb4h7cxbenghg3copvy` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeiguy7pkrcptg6c754ioig4mlkr7truccym3fpv6jwpjx2tmpdbzhi` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeicaj7hml27setiecug6kbbbk57pp25geyksujmfk7auegax5tanxq` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeianskoghhdffn4wqquup3rtziefq6jareutugb6a5zkbvuvctgk3i` | A client for the ABCI counter application.                                                                                 |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeidgnoxeedbnkhucxomna44al5hy66bcvdcbzcdstyjxstbz66z4bm` | Hello World ABCI application.                                                                                              |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeiagbvf6wf6mtgfzupwybxjr7lsi3kbai72qdbi66mo3qfwhppnsce` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeife6c4la6tyvqyauaanezkdmnissuhogfegvvnoz54chgwxunckn4` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeifcg2xabaabjg2cjzxfi4ina2zhzk2idhioc2c4u6x67cvfjbch7i` | ABCI application for testing the ABCI connection.                                                                          |
| agent/valory/abstract_abci/0.1.0                              | `bafybeicurjmnufs5ice2uzpofvzv5qofcc67zwtfxs5xqloxjvmfmvymai` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeiflu4kwi7v7gnaohx7dqmfz3x4ifp6t6a6xdyfgtr3dwu3vi6ypkm` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeiehqzno2htmg37mwcdaifptslsz2zpjwptq33gpdegpuaxknpoxza` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/hello_world/0.1.0                                | `bafybeigrgc7cxf244l366eknumnv7csclrzwwyokn6b3rrpoxofbezyefy` | Hello World ABCI example.                                                                                                  |
| agent/valory/register_reset/0.1.0                             | `bafybeicc2up44mgmr5cl2zowpkutoemxbswanmkasxe22fuhfshrtmetu4` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeid2rrl3cgxttkmeggojaefwvnpuxf5fmiprgzwcyxu5c3fwde3il4` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeiarw7go7qrpyamgxidx2nsolhztt2welz56rep4qfacedboqmtqsy` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeibbknolqzhtqxy5mjq35k5sqj3zmkfksulaz5y5vjlbbe33b2j3dy` | Agent for testing the ABCI connection.                                                                                     |
| service/valory/counter/0.1.0                                  | `bafybeic5ouoleyrkxqxiydu6mc26az434avvww6pid7hlasdl2njdqiv2e` | A set of agents incrementing a counter                                                                                     |
| service/valory/hello_world/0.1.0                              | `bafybeic5jkzuuusk6zppsqewc2pktydxphuhyhh2xnwbvszd2sirdh3vgu` | A simple demonstration of a simple ABCI application                                                                        |
| service/valory/register_reset/0.1.0                           | `bafybeidamkcsip4sxcomdhmc6qgtggegthm434335cean5wnq3ec7lsgie` | Test and debug tendermint reset mechanism.                                                                                 |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeibsv5nnlkfydhrq6oddavg4oxy7rgucvnooq5zz63bvetpffhw4mm` | ABCI application for dummy skill that registers and resets                                                                 |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeigodomstalqrj4y3xw5hzezlyoornffbwzr5eawv3gxpgq2dihsvm` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| contract/valory/multicall2/0.1.0                              | `bafybeiffhnnk3ibb3z53jxg4rfwcgjl657f56v3ld4rgafgavxxys3h74y` | The MakerDAO multicall2 contract.                                                                                          |
| protocol/open_aea/signing/1.0.0                               | `bafybeifuxs7gdg2okbn7uofymenjlmnih2wxwkym44lsgwmklgwuckxm2m` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeiapa5ilsobggnspoqhspftwolrx52udrwmaxdxgrk26heuvl4oooa` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeia5bxdua2i6chw6pg47bvoljzcpuqxzy4rdrorbdmcbnwmnfdobtu` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeigsvceac33asd6ecbqev34meyyjwu3rangenv6xp5rkxyz4krvcby` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeiasywsvax45qmugus5kxogejj66c5taen27h4voriodz7rgushtqa` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeieoeuy4brzimtnubmokwirhrx27ezls6cdnl5qik4rkykfle3nn2y` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeigfoz7d7si7s4jehvloq2zmiiocpbxcaathl3bxkyarxoerxq7g3a` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeihdnfdth3qgltefgrem7xyi4b3ejzaz67xglm2hbma2rfvpl2annq` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
